@@ -1,7 +1,7 @@
 django.jQuery(() => {
     $R('textarea[enable-redactor]', {
         linkTarget: '_blank',
-        plugins: ['imagemanager', 'video'],
+        plugins: ['imagemanager', 'video', 'widget'],
         fileUpload: '/redactor/file/',
         imageUpload: '/redactor/file/',
         imageManagerJson: '/redactor/file/'
